__requires__ = ['pandas', 'scipy', 'statsmodel']

import pandas as pd
import scipy.stats
import statsmodels.stats.multitest

questions = '''The color and luminance editing tools gave me sufficient control over the output image.
Recoloring the image by editing palette colors was convenient.
Luminance editing by adjusting a curve per palette color was convenient.
The automatically chosen palette colors matched my expectations.
Recoloring the image by placing pixel constraints was useful.
Placing and removing constraints in any order was useful.
I found the overall interface easy and fun to use.
I found the tool to be more effective at color and luminance editing compared to my most comfortable tool.'''.split('\n')

df = pd.read_csv( 'user study data.csv' )

alpha = 0.05

print( "Using t-test for the mean of one group of scores." )
pvals = []
for i, q in enumerate( questions ):
    data = df[q]
    result = scipy.stats.ttest_1samp( data, 3 )
    pvals.append( result.pvalue )

familywise = statsmodels.stats.multitest.multipletests( pvals, alpha = alpha, method = 'holm' )

for i, q in enumerate( questions ):
    print( f"Q{i+1}:", q )
    # print( df[q] )
    print( "p (uncorrected):", pvals[i] )
    print( "p (corrected):", familywise[1][i] )
    print( f"Significant at ɑ={alpha}", familywise[0][i] )

print( "-" * 60 )

print( "Full familywise data:" )
print( familywise )

print( "-" * 60 )

PLOT = False
if PLOT:
    import plot_likert
    import matplotlib as mpl
    
    plot_likert.plot_likert( df[ questions ], [1,2,3,4,5], label_max_width = 45 ).get_figure().savefig('plot.pdf')
